"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import video.coordinator.user_v1.user_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Participant(google.protobuf.message.Message):
    """those who are online in the call"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    VIDEO_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> video.coordinator.user_v1.user_pb2.User: ...
    role: builtins.str
    online: builtins.bool
    custom_json: builtins.bytes
    video: builtins.bool
    audio: builtins.bool
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Call creation date."""
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Call last update date."""
    def __init__(
        self,
        *,
        user: video.coordinator.user_v1.user_pb2.User | None = ...,
        role: builtins.str = ...,
        online: builtins.bool = ...,
        custom_json: builtins.bytes = ...,
        video: builtins.bool = ...,
        audio: builtins.bool = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "updated_at", b"updated_at", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "created_at", b"created_at", "custom_json", b"custom_json", "online", b"online", "role", b"role", "updated_at", b"updated_at", "user", b"user", "video", b"video"]) -> None: ...

global___Participant = Participant

class ParticipantRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    role: builtins.str
    custom_json: builtins.bytes
    """Call custom data"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Call creation date."""
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Call last update date."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        role: builtins.str = ...,
        custom_json: builtins.bytes = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "custom_json", b"custom_json", "role", b"role", "updated_at", b"updated_at", "user_id", b"user_id"]) -> None: ...

global___ParticipantRequest = ParticipantRequest



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/push_v1/push.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$video/coordinator/push_v1/push.proto\x12 stream.video.coordinator.push_v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xce\x03\n\x0cPushProvider\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\x17\n\x0f\x64isabled_reason\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x03\x61pn\x18\x06 \x01(\x0b\x32\x30.stream.video.coordinator.push_v1.ApnCredentialsH\x00\x12I\n\x08\x66irebase\x18\x07 \x01(\x0b\x32\x35.stream.video.coordinator.push_v1.FirebaseCredentialsH\x00\x12\x45\n\x06huawei\x18\x08 \x01(\x0b\x32\x33.stream.video.coordinator.push_v1.HuaweiCredentialsH\x00\x12\x45\n\x06xiaomi\x18\t \x01(\x0b\x32\x33.stream.video.coordinator.push_v1.XiaomiCredentialsH\x00\x42\r\n\x0b\x63redentials\"k\n\x0e\x41pnCredentials\x12\x10\n\x08\x61uth_key\x18\x01 \x01(\t\x12\x0e\n\x06key_id\x18\x02 \x01(\t\x12\x11\n\tapn_topic\x18\x03 \x01(\t\x12\x0f\n\x07team_id\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65velopment\x18\x05 \x01(\x08\"C\n\x13\x46irebaseCredentials\x12\x12\n\nserver_key\x18\x01 \x01(\t\x12\x18\n\x10\x63redentials_json\x18\x02 \x01(\t\"/\n\x11HuaweiCredentials\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"9\n\x11XiaomiCredentials\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\xcc\x01\n\x06\x44\x65vice\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12\x17\n\x0f\x64isabled_reason\x18\x04 \x01(\t\x12\x1a\n\x12push_provider_name\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"3\n\x0b\x44\x65viceInput\x12\n\n\x02id\x18\x01 \x01(\t\x12\x18\n\x10push_provider_id\x18\x02 \x01(\tB1B\x06PushV1P\x01Z\x07push_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.push_v1.push_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\006PushV1P\001Z\007push_v1\252\002\033Stream.Video.v1.Coordinator'
  _PUSHPROVIDER._serialized_start=108
  _PUSHPROVIDER._serialized_end=570
  _APNCREDENTIALS._serialized_start=572
  _APNCREDENTIALS._serialized_end=679
  _FIREBASECREDENTIALS._serialized_start=681
  _FIREBASECREDENTIALS._serialized_end=748
  _HUAWEICREDENTIALS._serialized_start=750
  _HUAWEICREDENTIALS._serialized_end=797
  _XIAOMICREDENTIALS._serialized_start=799
  _XIAOMICREDENTIALS._serialized_end=856
  _DEVICE._serialized_start=859
  _DEVICE._serialized_end=1063
  _DEVICEINPUT._serialized_start=1065
  _DEVICEINPUT._serialized_end=1116
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/app_v1/app.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"video/coordinator/app_v1/app.proto\x12\x1fstream.video.coordinator.app_v1\"T\n\x03\x41pp\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x41\n\x07webhook\x18\x02 \x01(\x0b\x32\x30.stream.video.coordinator.app_v1.WebhookSettings\"\x87\x01\n\x0fWebhookSettings\x12:\n\x04http\x18\x01 \x01(\x0b\x32,.stream.video.coordinator.app_v1.HttpWebhook\x12\x38\n\x03sqs\x18\x02 \x01(\x0b\x32+.stream.video.coordinator.app_v1.SqsWebhook\"\x1a\n\x0bHttpWebhook\x12\x0b\n\x03url\x18\x01 \x01(\t\"6\n\nSqsWebhook\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0e\n\x06secret\x18\x03 \x01(\tB/B\x05\x41ppV1P\x01Z\x06\x61pp_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.app_v1.app_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\005AppV1P\001Z\006app_v1\252\002\033Stream.Video.v1.Coordinator'
  _APP._serialized_start=71
  _APP._serialized_end=155
  _WEBHOOKSETTINGS._serialized_start=158
  _WEBHOOKSETTINGS._serialized_end=293
  _HTTPWEBHOOK._serialized_start=295
  _HTTPWEBHOOK._serialized_end=321
  _SQSWEBHOOK._serialized_start=323
  _SQSWEBHOOK._serialized_end=377
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Credentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    ICE_SERVERS_FIELD_NUMBER: builtins.int
    @property
    def server(self) -> global___EdgeServer:
        """Edge server to connect to"""
    token: builtins.str
    """The auth token needed to authenticate to the edge server"""
    @property
    def ice_servers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ICEServer]:
        """The list of ICE servers"""
    def __init__(
        self,
        *,
        server: global___EdgeServer | None = ...,
        token: builtins.str = ...,
        ice_servers: collections.abc.Iterable[global___ICEServer] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["server", b"server"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ice_servers", b"ice_servers", "server", b"server", "token", b"token"]) -> None: ...

global___Credentials = Credentials

class LatencyMeasurements(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class MeasurementsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Latency: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Latency | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    MEASUREMENTS_FIELD_NUMBER: builtins.int
    @property
    def measurements(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Latency]: ...
    def __init__(
        self,
        *,
        measurements: collections.abc.Mapping[builtins.str, global___Latency] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["measurements", b"measurements"]) -> None: ...

global___LatencyMeasurements = LatencyMeasurements

class Latency(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEASUREMENTS_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def measurements_seconds(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        measurements_seconds: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["measurements_seconds", b"measurements_seconds"]) -> None: ...

global___Latency = Latency

class Coordinates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAT_FIELD_NUMBER: builtins.int
    LONG_FIELD_NUMBER: builtins.int
    lat: builtins.float
    long: builtins.float
    def __init__(
        self,
        *,
        lat: builtins.float = ...,
        long: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lat", b"lat", "long", b"long"]) -> None: ...

global___Coordinates = Coordinates

class Edge(google.protobuf.message.Message):
    """Edges are where we deploy video servers"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    LATENCY_URL_FIELD_NUMBER: builtins.int
    COORDINATES_FIELD_NUMBER: builtins.int
    name: builtins.str
    latency_url: builtins.str
    @property
    def coordinates(self) -> global___Coordinates: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        latency_url: builtins.str = ...,
        coordinates: global___Coordinates | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["coordinates", b"coordinates"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["coordinates", b"coordinates", "latency_url", b"latency_url", "name", b"name"]) -> None: ...

global___Edge = Edge

class ICEServer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URLS_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    username: builtins.str
    password: builtins.str
    def __init__(
        self,
        *,
        urls: collections.abc.Iterable[builtins.str] | None = ...,
        username: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "urls", b"urls", "username", b"username"]) -> None: ...

global___ICEServer = ICEServer

class EdgeServer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    EDGE_NAME_FIELD_NUMBER: builtins.int
    url: builtins.str
    edge_name: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        edge_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["edge_name", b"edge_name", "url", b"url"]) -> None: ...

global___EdgeServer = EdgeServer



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/videoerr/error.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avideo/videoerr/error.proto\x12\x15stream.video.videoerr*\x8b\x04\n\x01\x45\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x17\n\x12\x41UTH_TOKEN_INVALID\x10\xe9\x07\x12\x1d\n\x18\x41UTH_TOKEN_NOT_VALID_YET\x10\xea\x07\x12!\n\x1c\x41UTH_TOKEN_USED_BEFORE_ISSUE\x10\xeb\x07\x12\x17\n\x12\x41UTH_TOKEN_EXPIRED\x10\xec\x07\x12!\n\x1c\x41UTH_TOKEN_INVALID_SIGNATURE\x10\xed\x07\x12\x19\n\x14\x41PI_KEY_NOT_PROVIDED\x10\xcd\x08\x12\x17\n\x12\x41PI_KEY_IS_UNKNOWN\x10\xce\x08\x12\x16\n\x11PERMISSION_DENIED\x10\xb1\t\x12\x1e\n\x19REQUEST_VALIDATION_FAILED\x10\x95\n\x12\x18\n\x13\x43\x41LL_TYPE_NOT_FOUND\x10\xf9\n\x12\x1d\n\x18\x43\x41LL_TYPE_ALREADY_EXISTS\x10\xfb\n\x12\x13\n\x0e\x43\x41LL_NOT_FOUND\x10\xdd\x0b\x12\x18\n\x13\x43\x41LL_ALREADY_EXISTS\x10\xde\x0b\x12\x1c\n\x17PUSH_PROVIDER_NOT_FOUND\x10\xc1\x0c\x12\x1a\n\x15PUSH_DEVICE_NOT_FOUND\x10\xc2\x0c\x12\x13\n\x0eUSER_NOT_FOUND\x10\xa5\r\x12\x18\n\x13USER_ALREADY_EXISTS\x10\xa6\r\x12!\n\x1cSFU_NO_DATACENTERS_AVAILABLE\x10\x89\x0e\x42\nZ\x08videoerrb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.videoerr.error_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\010videoerr'
  _E._serialized_start=54
  _E._serialized_end=577
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import video.coordinator.call_v1.call_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RecordingStarted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___RecordingStarted = RecordingStarted

class RecordingStopped(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___RecordingStopped = RecordingStopped

class UserUpdated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_id", b"user_id"]) -> None: ...

global___UserUpdated = UserUpdated

class BroadcastStarted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___BroadcastStarted = BroadcastStarted

class BroadcastEnded(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___BroadcastEnded = BroadcastEnded

class CallMembersCreated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    RINGING_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    ringing: builtins.bool
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
        ringing: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details", "ringing", b"ringing"]) -> None: ...

global___CallMembersCreated = CallMembersCreated

class CallMembersUpdated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___CallMembersUpdated = CallMembersUpdated

class CallMembersDeleted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___CallMembersDeleted = CallMembersDeleted

class CallCreated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    RINGING_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    ringing: builtins.bool
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
        ringing: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details", "ringing", b"ringing"]) -> None: ...

global___CallCreated = CallCreated

class CallUpdated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___CallUpdated = CallUpdated

class CallEnded(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___CallEnded = CallEnded

class CallDeleted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___CallDeleted = CallDeleted

class CallAccepted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    SENDER_USER_ID_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    sender_user_id: builtins.str
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
        sender_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details", "sender_user_id", b"sender_user_id"]) -> None: ...

global___CallAccepted = CallAccepted

class CallRejected(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    SENDER_USER_ID_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    sender_user_id: builtins.str
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
        sender_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details", "sender_user_id", b"sender_user_id"]) -> None: ...

global___CallRejected = CallRejected

class CallCancelled(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    SENDER_USER_ID_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    sender_user_id: builtins.str
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
        sender_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details", "sender_user_id", b"sender_user_id"]) -> None: ...

global___CallCancelled = CallCancelled

class CallCustom(google.protobuf.message.Message):
    """A custom event type"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    SENDER_USER_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DATA_JSON_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    sender_user_id: builtins.str
    type: builtins.str
    """The type of the event"""
    data_json: builtins.bytes
    """The data in the event"""
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
        sender_user_id: builtins.str = ...,
        type: builtins.str = ...,
        data_json: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details", "data_json", b"data_json", "sender_user_id", b"sender_user_id", "type", b"type"]) -> None: ...

global___CallCustom = CallCustom



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/member_v1/member.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(video/coordinator/member_v1/member.proto\x12\"stream.video.coordinator.member_v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"\xc9\x01\n\x06Member\x12\x19\n\x08\x63\x61ll_cid\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07user_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04role\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x0b\x63ustom_json\x18\x04 \x01(\x0c\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB5B\x08MemberV1P\x01Z\tmember_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.member_v1.member_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\010MemberV1P\001Z\tmember_v1\252\002\033Stream.Video.v1.Coordinator'
  _MEMBER.fields_by_name['call_cid']._options = None
  _MEMBER.fields_by_name['call_cid']._serialized_options = b'\372B\004r\002\020\001'
  _MEMBER.fields_by_name['user_id']._options = None
  _MEMBER.fields_by_name['user_id']._serialized_options = b'\372B\004r\002\020\001'
  _MEMBER.fields_by_name['role']._options = None
  _MEMBER.fields_by_name['role']._serialized_options = b'\372B\004r\002\020\001'
  _MEMBER._serialized_start=139
  _MEMBER._serialized_end=340
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['stream_video',
 'stream_video.gen',
 'stream_video.gen.permissions.permissions_v1_rpc',
 'stream_video.gen.validate',
 'stream_video.gen.video.coordinator.app_v1',
 'stream_video.gen.video.coordinator.broadcast_v1',
 'stream_video.gen.video.coordinator.call_v1',
 'stream_video.gen.video.coordinator.client_v1_rpc',
 'stream_video.gen.video.coordinator.edge_v1',
 'stream_video.gen.video.coordinator.event_v1',
 'stream_video.gen.video.coordinator.member_v1',
 'stream_video.gen.video.coordinator.participant_v1',
 'stream_video.gen.video.coordinator.push_v1',
 'stream_video.gen.video.coordinator.recording_v1',
 'stream_video.gen.video.coordinator.server_v1_rpc',
 'stream_video.gen.video.coordinator.stat_v1',
 'stream_video.gen.video.coordinator.user_v1',
 'stream_video.gen.video.coordinator.utils_v1',
 'stream_video.gen.video.sfu.cascading_rpc',
 'stream_video.gen.video.sfu.event',
 'stream_video.gen.video.sfu.models',
 'stream_video.gen.video.sfu.remote_control_rpc',
 'stream_video.gen.video.sfu.signal_rpc',
 'stream_video.gen.video.videoerr']

package_data = \
{'': ['*']}

install_requires = \
['PyJWT>=2.4.0,<3.0.0',
 'protobuf>=4.21.6,<5.0.0',
 'twirp>=0.0.7,<0.0.8',
 'typed-ast>=1.5.4,<2.0.0']

setup_kwargs = {
    'name': 'stream-video',
    'version': '0.0.1',
    'description': '',
    'long_description': '',
    'author': 'Stream.io',
    'author_email': 'support@getstream.io',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Subscription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLISHER_ID_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    CODED_FIELD_NUMBER: builtins.int
    publisher_id: builtins.str
    rid: builtins.str
    coded: builtins.str
    def __init__(
        self,
        *,
        publisher_id: builtins.str = ...,
        rid: builtins.str = ...,
        coded: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coded", b"coded", "publisher_id", b"publisher_id", "rid", b"rid"]) -> None: ...

global___Subscription = Subscription

class Participant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    @property
    def subscriptions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Subscription]: ...
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        subscriptions: collections.abc.Iterable[global___Subscription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["subscriptions", b"subscriptions", "user_id", b"user_id"]) -> None: ...

global___Participant = Participant

class CallState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARTICIPANTS_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    @property
    def participants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Participant]: ...
    sequence: builtins.int
    def __init__(
        self,
        *,
        participants: collections.abc.Iterable[global___Participant] | None = ...,
        sequence: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["participants", b"participants", "sequence", b"sequence"]) -> None: ...

global___CallState = CallState

class JoinCallRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    LOCAL_STATE_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    @property
    def local_state(self) -> global___CallState: ...
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
        local_state: global___CallState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["local_state", b"local_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid", "local_state", b"local_state"]) -> None: ...

global___JoinCallRequest = JoinCallRequest

class JoinCallResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SFU_ADDRESSES_FIELD_NUMBER: builtins.int
    LOCAL_STATE_FIELD_NUMBER: builtins.int
    @property
    def sfu_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def local_state(self) -> global___CallState: ...
    def __init__(
        self,
        *,
        sfu_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        local_state: global___CallState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["local_state", b"local_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["local_state", b"local_state", "sfu_addresses", b"sfu_addresses"]) -> None: ...

global___JoinCallResponse = JoinCallResponse

class GetCallStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetCallStateRequest = GetCallStateRequest

class GetCallStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCAL_STATE_FIELD_NUMBER: builtins.int
    @property
    def local_state(self) -> global___CallState: ...
    def __init__(
        self,
        *,
        local_state: global___CallState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["local_state", b"local_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["local_state", b"local_state"]) -> None: ...

global___GetCallStateResponse = GetCallStateResponse

class AudioMuteChanged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AudioMuteChanged = AudioMuteChanged

class Healthcheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Healthcheck = Healthcheck

class VideoMuteChanged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___VideoMuteChanged = VideoMuteChanged

class SendEventRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_FIELD_NUMBER: builtins.int
    AUDIO_MUTE_CHANGED_FIELD_NUMBER: builtins.int
    VIDEO_MUTE_CHANGED_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    """sequence is specific to the local state of the SFU sending the event
    receivers can use this to detect out of order delivery or lost messages
    when that happens
    """
    sequence: builtins.int
    @property
    def health_check(self) -> global___Healthcheck: ...
    @property
    def audio_mute_changed(self) -> global___AudioMuteChanged: ...
    @property
    def video_mute_changed(self) -> global___VideoMuteChanged:
        """add participant (marcelo joins the call)
        remove participant (marcelo leaves the call)
        add publisher track (marcelo starts audio or video track)
        remove publisher track (marcelo stops audio or video track)
        add subscription (marcelo subscribes to tommaso high-quality track)
        remove subscription (marcelo unsubscribes from tommaso)
        change subscription (marcelo changes the subscription to Tommaso from high to medium)
        audio levels - TODO: this does not change anything, its just a user event we want to forward to all clients
        dominant speaker changed - TODO: this one is tricky because you need to analyze all audio levels from all clients,
        perhaps sharing audio levels is enough
        """
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
        sequence: builtins.int = ...,
        health_check: global___Healthcheck | None = ...,
        audio_mute_changed: global___AudioMuteChanged | None = ...,
        video_mute_changed: global___VideoMuteChanged | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audio_mute_changed", b"audio_mute_changed", "event", b"event", "health_check", b"health_check", "video_mute_changed", b"video_mute_changed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio_mute_changed", b"audio_mute_changed", "call_cid", b"call_cid", "event", b"event", "health_check", b"health_check", "sequence", b"sequence", "video_mute_changed", b"video_mute_changed"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event", b"event"]) -> typing_extensions.Literal["health_check", "audio_mute_changed", "video_mute_changed"] | None: ...

global___SendEventRequest = SendEventRequest

class SendEventResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SendEventResponse = SendEventResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/sfu/signal_rpc/signal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video.sfu.models import models_pb2 as video_dot_sfu_dot_models_dot_models__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!video/sfu/signal_rpc/signal.proto\x12\x17stream.video.sfu.signal\x1a\x1dvideo/sfu/models/models.proto\"q\n\x19UpdateVideoQualityRequest\x12@\n\x10stream_qualities\x18\x01 \x03(\x0b\x32&.stream.video.sfu.models.StreamQuality\x12\x12\n\nsession_id\x18\x02 \x01(\t\"\x1c\n\x1aUpdateVideoQualityResponse\"\xc6\x01\n\x16UpdateMuteStateRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12G\n\x12\x61udio_mute_changed\x18\x02 \x01(\x0b\x32).stream.video.sfu.signal.AudioMuteChangedH\x00\x12G\n\x12video_mute_changed\x18\x03 \x01(\x0b\x32).stream.video.sfu.signal.VideoMuteChangedH\x00\x42\x06\n\x04mute\"\x19\n\x17UpdateMuteStateResponse\"!\n\x10\x41udioMuteChanged\x12\r\n\x05muted\x18\x01 \x01(\x08\"!\n\x10VideoMuteChanged\x12\r\n\x05muted\x18\x02 \x01(\x08\"\xee\x01\n\x1aUpdateSubscriptionsRequest\x12]\n\rsubscriptions\x18\x01 \x03(\x0b\x32\x46.stream.video.sfu.signal.UpdateSubscriptionsRequest.SubscriptionsEntry\x12\x12\n\nsession_id\x18\x02 \x01(\t\x1a]\n\x12SubscriptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.stream.video.sfu.models.VideoDimension:\x02\x38\x01\"j\n\x11SendAnswerRequest\x12\x34\n\tpeer_type\x18\x01 \x01(\x0e\x32!.stream.video.sfu.models.PeerType\x12\x0b\n\x03sdp\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x04 \x01(\t\"\x14\n\x12SendAnswerResponse\"\xd9\x01\n\x13IceCandidateRequest\x12\x11\n\tpublisher\x18\x01 \x01(\x08\x12\x11\n\tcandidate\x18\x02 \x01(\t\x12\x14\n\x07sdp_mid\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x0fsdp_mline_index\x18\x04 \x01(\rH\x01\x88\x01\x01\x12\x1e\n\x11username_fragment\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x12\n\nsession_id\x18\x07 \x01(\tB\n\n\x08_sdp_midB\x12\n\x10_sdp_mline_indexB\x14\n\x12_username_fragment\"\x14\n\x12ICETrickleResponse\"\x1d\n\x1bUpdateSubscriptionsResponse\"6\n\x13SetPublisherRequest\x12\x0b\n\x03sdp\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t\"7\n\x14SetPublisherResponse\x12\x0b\n\x03sdp\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t\"2\n\x0e\x43onnectRequest\x12\x11\n\tsdp_offer\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"%\n\x0f\x43onnectResponse\x12\x12\n\nsdp_answer\x18\x01 \x01(\t\"\x9c\x01\n\rSignalRequest\x12>\n\tsubscribe\x18\x01 \x01(\x0b\x32).stream.video.sfu.signal.SubscribeRequestH\x00\x12:\n\x07publish\x18\x02 \x01(\x0b\x32\'.stream.video.sfu.signal.PublishRequestH\x00\x42\x0f\n\revent_payload\"\x9c\x01\n\x0bSignalEvent\x12?\n\tsubscribe\x18\x01 \x01(\x0b\x32*.stream.video.sfu.signal.SubscribeResponseH\x00\x12;\n\x07publish\x18\x02 \x01(\x0b\x32(.stream.video.sfu.signal.PublishResponseH\x00\x42\x0f\n\revent_payload\"E\n\x10SubscribeRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x11\n\tsdp_offer\x18\x02 \x01(\t\x12\x0f\n\x07quality\x18\x03 \x01(\t\"$\n\x11SubscribeResponse\x12\x0f\n\x07quality\x18\x02 \x01(\t\"2\n\x0ePublishRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x11\n\tsdp_offer\x18\x02 \x01(\t\"%\n\x0fPublishResponse\x12\x12\n\nsdp_answer\x18\x02 \x01(\t2\xbb\x05\n\x0cSignalServer\x12k\n\x0cSetPublisher\x12,.stream.video.sfu.signal.SetPublisherRequest\x1a-.stream.video.sfu.signal.SetPublisherResponse\x12\x65\n\nSendAnswer\x12*.stream.video.sfu.signal.SendAnswerRequest\x1a+.stream.video.sfu.signal.SendAnswerResponse\x12^\n\nIceTrickle\x12#.stream.video.sfu.models.ICETrickle\x1a+.stream.video.sfu.signal.ICETrickleResponse\x12\x80\x01\n\x13UpdateSubscriptions\x12\x33.stream.video.sfu.signal.UpdateSubscriptionsRequest\x1a\x34.stream.video.sfu.signal.UpdateSubscriptionsResponse\x12t\n\x0fUpdateMuteState\x12/.stream.video.sfu.signal.UpdateMuteStateRequest\x1a\x30.stream.video.sfu.signal.UpdateMuteStateResponse\x12~\n\x13RequestVideoQuality\x12\x32.stream.video.sfu.signal.UpdateVideoQualityRequest\x1a\x33.stream.video.sfu.signal.UpdateVideoQualityResponseB5B\x0bSfuSignalV1P\x01Z\x0esfu_signal_rpc\xaa\x02\x13Stream.Video.v1.Sfub\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.sfu.signal_rpc.signal_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\013SfuSignalV1P\001Z\016sfu_signal_rpc\252\002\023Stream.Video.v1.Sfu'
  _UPDATESUBSCRIPTIONSREQUEST_SUBSCRIPTIONSENTRY._options = None
  _UPDATESUBSCRIPTIONSREQUEST_SUBSCRIPTIONSENTRY._serialized_options = b'8\001'
  _UPDATEVIDEOQUALITYREQUEST._serialized_start=93
  _UPDATEVIDEOQUALITYREQUEST._serialized_end=206
  _UPDATEVIDEOQUALITYRESPONSE._serialized_start=208
  _UPDATEVIDEOQUALITYRESPONSE._serialized_end=236
  _UPDATEMUTESTATEREQUEST._serialized_start=239
  _UPDATEMUTESTATEREQUEST._serialized_end=437
  _UPDATEMUTESTATERESPONSE._serialized_start=439
  _UPDATEMUTESTATERESPONSE._serialized_end=464
  _AUDIOMUTECHANGED._serialized_start=466
  _AUDIOMUTECHANGED._serialized_end=499
  _VIDEOMUTECHANGED._serialized_start=501
  _VIDEOMUTECHANGED._serialized_end=534
  _UPDATESUBSCRIPTIONSREQUEST._serialized_start=537
  _UPDATESUBSCRIPTIONSREQUEST._serialized_end=775
  _UPDATESUBSCRIPTIONSREQUEST_SUBSCRIPTIONSENTRY._serialized_start=682
  _UPDATESUBSCRIPTIONSREQUEST_SUBSCRIPTIONSENTRY._serialized_end=775
  _SENDANSWERREQUEST._serialized_start=777
  _SENDANSWERREQUEST._serialized_end=883
  _SENDANSWERRESPONSE._serialized_start=885
  _SENDANSWERRESPONSE._serialized_end=905
  _ICECANDIDATEREQUEST._serialized_start=908
  _ICECANDIDATEREQUEST._serialized_end=1125
  _ICETRICKLERESPONSE._serialized_start=1127
  _ICETRICKLERESPONSE._serialized_end=1147
  _UPDATESUBSCRIPTIONSRESPONSE._serialized_start=1149
  _UPDATESUBSCRIPTIONSRESPONSE._serialized_end=1178
  _SETPUBLISHERREQUEST._serialized_start=1180
  _SETPUBLISHERREQUEST._serialized_end=1234
  _SETPUBLISHERRESPONSE._serialized_start=1236
  _SETPUBLISHERRESPONSE._serialized_end=1291
  _CONNECTREQUEST._serialized_start=1293
  _CONNECTREQUEST._serialized_end=1343
  _CONNECTRESPONSE._serialized_start=1345
  _CONNECTRESPONSE._serialized_end=1382
  _SIGNALREQUEST._serialized_start=1385
  _SIGNALREQUEST._serialized_end=1541
  _SIGNALEVENT._serialized_start=1544
  _SIGNALEVENT._serialized_end=1700
  _SUBSCRIBEREQUEST._serialized_start=1702
  _SUBSCRIBEREQUEST._serialized_end=1771
  _SUBSCRIBERESPONSE._serialized_start=1773
  _SUBSCRIBERESPONSE._serialized_end=1809
  _PUBLISHREQUEST._serialized_start=1811
  _PUBLISHREQUEST._serialized_end=1861
  _PUBLISHRESPONSE._serialized_start=1863
  _PUBLISHRESPONSE._serialized_end=1900
  _SIGNALSERVER._serialized_start=1903
  _SIGNALSERVER._serialized_end=2602
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/sfu/event/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video.sfu.models import models_pb2 as video_dot_sfu_dot_models_dot_models__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cvideo/sfu/event/events.proto\x12\x16stream.video.sfu.event\x1a\x1dvideo/sfu/models/models.proto\"\xa2\x08\n\x08SfuEvent\x12\x43\n\x10subscriber_offer\x18\x01 \x01(\x0b\x32\'.stream.video.sfu.event.SubscriberOfferH\x00\x12\x43\n\x10publisher_answer\x18\x0e \x01(\x0b\x32\'.stream.video.sfu.event.PublisherAnswerH\x00\x12V\n\x1a\x63onnection_quality_changed\x18\x02 \x01(\x0b\x32\x30.stream.video.sfu.event.ConnectionQualityChangedH\x00\x12H\n\x13\x61udio_level_changed\x18\x03 \x01(\x0b\x32).stream.video.sfu.event.AudioLevelChangedH\x00\x12:\n\x0bice_trickle\x18\x04 \x01(\x0b\x32#.stream.video.sfu.models.ICETrickleH\x00\x12N\n\x16\x63hange_publish_quality\x18\x06 \x01(\x0b\x32,.stream.video.sfu.event.ChangePublishQualityH\x00\x12H\n\x13local_device_change\x18\x07 \x01(\x0b\x32).stream.video.sfu.event.LocalDeviceChangeH\x00\x12\x46\n\x12mute_state_changed\x18\x08 \x01(\x0b\x32(.stream.video.sfu.event.MuteStateChangedH\x00\x12L\n\x15video_quality_changed\x18\t \x01(\x0b\x32+.stream.video.sfu.event.VideoQualityChangedH\x00\x12G\n\x12participant_joined\x18\n \x01(\x0b\x32).stream.video.sfu.event.ParticipantJoinedH\x00\x12\x43\n\x10participant_left\x18\x0b \x01(\x0b\x32\'.stream.video.sfu.event.ParticipantLeftH\x00\x12R\n\x18\x64ominant_speaker_changed\x18\x0c \x01(\x0b\x32..stream.video.sfu.event.DominantSpeakerChangedH\x00\x12=\n\rjoin_response\x18\r \x01(\x0b\x32$.stream.video.sfu.event.JoinResponseH\x00\x12L\n\x15health_check_response\x18\x0f \x01(\x0b\x32+.stream.video.sfu.event.HealthCheckResponseH\x00\x42\x0f\n\revent_payload\"\xa8\x01\n\nSfuRequest\x12;\n\x0cjoin_request\x18\x01 \x01(\x0b\x32#.stream.video.sfu.event.JoinRequestH\x00\x12J\n\x14health_check_request\x18\x02 \x01(\x0b\x32*.stream.video.sfu.event.HealthCheckRequestH\x00\x42\x11\n\x0frequest_payload\"(\n\x12HealthCheckRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\")\n\x13HealthCheckResponse\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\x81\x01\n\x0bJoinRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x0f\n\x07publish\x18\x03 \x01(\x08\x12>\n\x0e\x63odec_settings\x18\x04 \x01(\x0b\x32&.stream.video.sfu.models.CodecSettings\"^\n\x0cJoinResponse\x12\x36\n\ncall_state\x18\x01 \x01(\x0b\x32\".stream.video.sfu.models.CallState\x12\x16\n\x0eown_session_id\x18\x02 \x01(\t\"{\n\x11ParticipantJoined\x12+\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x1d.stream.video.sfu.models.Call\x12\x39\n\x0bparticipant\x18\x02 \x01(\x0b\x32$.stream.video.sfu.models.Participant\"y\n\x0fParticipantLeft\x12+\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x1d.stream.video.sfu.models.Call\x12\x39\n\x0bparticipant\x18\x02 \x01(\x0b\x32$.stream.video.sfu.models.Participant\"M\n\x10MuteStateChanged\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x13\n\x0b\x61udio_muted\x18\x02 \x01(\x08\x12\x13\n\x0bvideo_muted\x18\x03 \x01(\x08\"W\n\x13VideoQualityChanged\x12@\n\x10stream_qualities\x18\x01 \x03(\x0b\x32&.stream.video.sfu.models.StreamQuality\"\x1e\n\x0fSubscriberOffer\x12\x0b\n\x03sdp\x18\x01 \x01(\t\"\x1e\n\x0fPublisherAnswer\x12\x0b\n\x03sdp\x18\x01 \x01(\t\"!\n\x11LocalDeviceChange\x12\x0c\n\x04type\x18\x01 \x01(\t\"(\n\x13ICECandidateTrickle\x12\x11\n\tcandidate\x18\x01 \x01(\t\"s\n\x18\x43onnectionQualityChanged\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x46\n\x12\x63onnection_quality\x18\x02 \x01(\x0e\x32*.stream.video.sfu.models.ConnectionQuality\")\n\x16\x44ominantSpeakerChanged\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"M\n\x11\x41udioLevelChanged\x12\x38\n\x0c\x61udio_levels\x18\x01 \x03(\x0b\x32\".stream.video.sfu.event.AudioLevel\",\n\nAudioLevel\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\x02\"\x13\n\x11\x41udioLayerSetting\"*\n\x11\x41udioMediaRequest\x12\x15\n\rchannel_count\x18\x01 \x01(\x05\"\xb9\x01\n\x0b\x41udioSender\x12@\n\rmedia_request\x18\x01 \x01(\x0b\x32).stream.video.sfu.event.AudioMediaRequest\x12-\n\x05\x63odec\x18\x02 \x01(\x0b\x32\x1e.stream.video.sfu.models.Codec\x12\x39\n\x06layers\x18\x03 \x03(\x0b\x32).stream.video.sfu.event.AudioLayerSetting\"X\n\x11VideoMediaRequest\x12\x14\n\x0cideal_height\x18\x01 \x01(\x05\x12\x13\n\x0bideal_width\x18\x02 \x01(\x05\x12\x18\n\x10ideal_frame_rate\x18\x03 \x01(\x05\"\xc6\x02\n\x11VideoLayerSetting\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x13\n\x0bmax_bitrate\x18\x03 \x01(\x05\x12 \n\x18scale_resolution_down_by\x18\x04 \x01(\x02\x12\x44\n\x08priority\x18\x05 \x01(\x0e\x32\x32.stream.video.sfu.event.VideoLayerSetting.Priority\x12-\n\x05\x63odec\x18\x06 \x01(\x0b\x32\x1e.stream.video.sfu.models.Codec\"g\n\x08Priority\x12\x1d\n\x19PRIORITY_HIGH_UNSPECIFIED\x10\x00\x12\x10\n\x0cPRIORITY_LOW\x10\x01\x12\x13\n\x0fPRIORITY_MEDIUM\x10\x02\x12\x15\n\x11PRIORITY_VERY_LOW\x10\x03\"\xb9\x01\n\x0bVideoSender\x12@\n\rmedia_request\x18\x01 \x01(\x0b\x32).stream.video.sfu.event.VideoMediaRequest\x12-\n\x05\x63odec\x18\x02 \x01(\x0b\x32\x1e.stream.video.sfu.models.Codec\x12\x39\n\x06layers\x18\x03 \x03(\x0b\x32).stream.video.sfu.event.VideoLayerSetting\"\x8e\x01\n\x14\x43hangePublishQuality\x12:\n\raudio_senders\x18\x01 \x03(\x0b\x32#.stream.video.sfu.event.AudioSender\x12:\n\rvideo_senders\x18\x02 \x03(\x0b\x32#.stream.video.sfu.event.VideoSenderB1B\x0bSfuEventsV1P\x01Z\nsfu_events\xaa\x02\x13Stream.Video.v1.Sfub\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.sfu.event.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\013SfuEventsV1P\001Z\nsfu_events\252\002\023Stream.Video.v1.Sfu'
  _SFUEVENT._serialized_start=88
  _SFUEVENT._serialized_end=1146
  _SFUREQUEST._serialized_start=1149
  _SFUREQUEST._serialized_end=1317
  _HEALTHCHECKREQUEST._serialized_start=1319
  _HEALTHCHECKREQUEST._serialized_end=1359
  _HEALTHCHECKRESPONSE._serialized_start=1361
  _HEALTHCHECKRESPONSE._serialized_end=1402
  _JOINREQUEST._serialized_start=1405
  _JOINREQUEST._serialized_end=1534
  _JOINRESPONSE._serialized_start=1536
  _JOINRESPONSE._serialized_end=1630
  _PARTICIPANTJOINED._serialized_start=1632
  _PARTICIPANTJOINED._serialized_end=1755
  _PARTICIPANTLEFT._serialized_start=1757
  _PARTICIPANTLEFT._serialized_end=1878
  _MUTESTATECHANGED._serialized_start=1880
  _MUTESTATECHANGED._serialized_end=1957
  _VIDEOQUALITYCHANGED._serialized_start=1959
  _VIDEOQUALITYCHANGED._serialized_end=2046
  _SUBSCRIBEROFFER._serialized_start=2048
  _SUBSCRIBEROFFER._serialized_end=2078
  _PUBLISHERANSWER._serialized_start=2080
  _PUBLISHERANSWER._serialized_end=2110
  _LOCALDEVICECHANGE._serialized_start=2112
  _LOCALDEVICECHANGE._serialized_end=2145
  _ICECANDIDATETRICKLE._serialized_start=2147
  _ICECANDIDATETRICKLE._serialized_end=2187
  _CONNECTIONQUALITYCHANGED._serialized_start=2189
  _CONNECTIONQUALITYCHANGED._serialized_end=2304
  _DOMINANTSPEAKERCHANGED._serialized_start=2306
  _DOMINANTSPEAKERCHANGED._serialized_end=2347
  _AUDIOLEVELCHANGED._serialized_start=2349
  _AUDIOLEVELCHANGED._serialized_end=2426
  _AUDIOLEVEL._serialized_start=2428
  _AUDIOLEVEL._serialized_end=2472
  _AUDIOLAYERSETTING._serialized_start=2474
  _AUDIOLAYERSETTING._serialized_end=2493
  _AUDIOMEDIAREQUEST._serialized_start=2495
  _AUDIOMEDIAREQUEST._serialized_end=2537
  _AUDIOSENDER._serialized_start=2540
  _AUDIOSENDER._serialized_end=2725
  _VIDEOMEDIAREQUEST._serialized_start=2727
  _VIDEOMEDIAREQUEST._serialized_end=2815
  _VIDEOLAYERSETTING._serialized_start=2818
  _VIDEOLAYERSETTING._serialized_end=3144
  _VIDEOLAYERSETTING_PRIORITY._serialized_start=3041
  _VIDEOLAYERSETTING_PRIORITY._serialized_end=3144
  _VIDEOSENDER._serialized_start=3147
  _VIDEOSENDER._serialized_end=3332
  _CHANGEPUBLISHQUALITY._serialized_start=3335
  _CHANGEPUBLISHQUALITY._serialized_end=3477
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/participant_v1/participant.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from video.coordinator.user_v1 import user_pb2 as video_dot_coordinator_dot_user__v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2video/coordinator/participant_v1/participant.proto\x12\'stream.video.coordinator.participant_v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$video/coordinator/user_v1/user.proto\"\xf4\x01\n\x0bParticipant\x12\x34\n\x04user\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.user_v1.User\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x0e\n\x06online\x18\x03 \x01(\x08\x12\x13\n\x0b\x63ustom_json\x18\x04 \x01(\x0c\x12\r\n\x05video\x18\x05 \x01(\x08\x12\r\n\x05\x61udio\x18\x06 \x01(\x08\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa8\x01\n\x12ParticipantRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x13\n\x0b\x63ustom_json\x18\x03 \x01(\x0c\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB?B\rParticipantV1P\x01Z\x0eparticipant_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.participant_v1.participant_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\rParticipantV1P\001Z\016participant_v1\252\002\033Stream.Video.v1.Coordinator'
  _PARTICIPANT._serialized_start=167
  _PARTICIPANT._serialized_end=411
  _PARTICIPANTREQUEST._serialized_start=414
  _PARTICIPANTREQUEST._serialized_end=582
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by https://github.com/verloop/twirpy/protoc-gen-twirpy.  DO NOT EDIT!
# source: video/coordinator/client_v1_rpc/client_rpc.proto

from google.protobuf import symbol_database as _symbol_database

from twirp.base import Endpoint
from twirp.server import TwirpServer
from twirp.client import TwirpClient

_sym_db = _symbol_database.Default()

class ClientRPCServer(TwirpServer):

	def __init__(self, *args, service, server_path_prefix="/twirp"):
		super().__init__(service=service)
		self._prefix = F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC"
		self._endpoints = {
			"CreateCall": Endpoint(
				service_name="ClientRPC",
				name="CreateCall",
				function=getattr(service, "CreateCall"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.CreateCallRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.CreateCallResponse"),
			),
			"GetOrCreateCall": Endpoint(
				service_name="ClientRPC",
				name="GetOrCreateCall",
				function=getattr(service, "GetOrCreateCall"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.GetOrCreateCallRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.GetOrCreateCallResponse"),
			),
			"JoinCall": Endpoint(
				service_name="ClientRPC",
				name="JoinCall",
				function=getattr(service, "JoinCall"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.JoinCallRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.JoinCallResponse"),
			),
			"GetCallEdgeServer": Endpoint(
				service_name="ClientRPC",
				name="GetCallEdgeServer",
				function=getattr(service, "GetCallEdgeServer"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.GetCallEdgeServerRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.GetCallEdgeServerResponse"),
			),
			"UpdateCall": Endpoint(
				service_name="ClientRPC",
				name="UpdateCall",
				function=getattr(service, "UpdateCall"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.UpdateCallRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.UpdateCallResponse"),
			),
			"QueryCalls": Endpoint(
				service_name="ClientRPC",
				name="QueryCalls",
				function=getattr(service, "QueryCalls"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.QueryCallsRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.QueryCallsResponse"),
			),
			"QueryMembers": Endpoint(
				service_name="ClientRPC",
				name="QueryMembers",
				function=getattr(service, "QueryMembers"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.QueryMembersRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.QueryMembersResponse"),
			),
			"CreateDevice": Endpoint(
				service_name="ClientRPC",
				name="CreateDevice",
				function=getattr(service, "CreateDevice"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.CreateDeviceRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.CreateDeviceResponse"),
			),
			"DeleteDevice": Endpoint(
				service_name="ClientRPC",
				name="DeleteDevice",
				function=getattr(service, "DeleteDevice"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.DeleteDeviceRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.DeleteDeviceResponse"),
			),
			"QueryDevices": Endpoint(
				service_name="ClientRPC",
				name="QueryDevices",
				function=getattr(service, "QueryDevices"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.QueryDevicesRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.QueryDevicesResponse"),
			),
			"UpsertCallMembers": Endpoint(
				service_name="ClientRPC",
				name="UpsertCallMembers",
				function=getattr(service, "UpsertCallMembers"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.UpsertCallMembersRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.UpsertCallMembersResponse"),
			),
			"DeleteCallMembers": Endpoint(
				service_name="ClientRPC",
				name="DeleteCallMembers",
				function=getattr(service, "DeleteCallMembers"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.DeleteCallMembersRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.DeleteCallMembersResponse"),
			),
			"SendEvent": Endpoint(
				service_name="ClientRPC",
				name="SendEvent",
				function=getattr(service, "SendEvent"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.SendEventRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.SendEventResponse"),
			),
			"SendCustomEvent": Endpoint(
				service_name="ClientRPC",
				name="SendCustomEvent",
				function=getattr(service, "SendCustomEvent"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.SendCustomEventRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.SendCustomEventResponse"),
			),
			"ReportCallStats": Endpoint(
				service_name="ClientRPC",
				name="ReportCallStats",
				function=getattr(service, "ReportCallStats"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.ReportCallStatsRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.ReportCallStatsResponse"),
			),
			"ReportCallStatEvent": Endpoint(
				service_name="ClientRPC",
				name="ReportCallStatEvent",
				function=getattr(service, "ReportCallStatEvent"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.ReportCallStatEventRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.ReportCallStatEventResponse"),
			),
			"ReviewCall": Endpoint(
				service_name="ClientRPC",
				name="ReviewCall",
				function=getattr(service, "ReviewCall"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.ReviewCallRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.ReviewCallResponse"),
			),
			"ReportIssue": Endpoint(
				service_name="ClientRPC",
				name="ReportIssue",
				function=getattr(service, "ReportIssue"),
				input=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.ReportIssueRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.ReportIssueResponse"),
			),
		}

class ClientRPCClient(TwirpClient):

	def CreateCall(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/CreateCall",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.CreateCallResponse"),
			**kwargs,
		)

	def GetOrCreateCall(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/GetOrCreateCall",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.GetOrCreateCallResponse"),
			**kwargs,
		)

	def JoinCall(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/JoinCall",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.JoinCallResponse"),
			**kwargs,
		)

	def GetCallEdgeServer(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/GetCallEdgeServer",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.GetCallEdgeServerResponse"),
			**kwargs,
		)

	def UpdateCall(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/UpdateCall",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.UpdateCallResponse"),
			**kwargs,
		)

	def QueryCalls(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/QueryCalls",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.QueryCallsResponse"),
			**kwargs,
		)

	def QueryMembers(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/QueryMembers",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.QueryMembersResponse"),
			**kwargs,
		)

	def CreateDevice(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/CreateDevice",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.CreateDeviceResponse"),
			**kwargs,
		)

	def DeleteDevice(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/DeleteDevice",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.DeleteDeviceResponse"),
			**kwargs,
		)

	def QueryDevices(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/QueryDevices",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.QueryDevicesResponse"),
			**kwargs,
		)

	def UpsertCallMembers(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/UpsertCallMembers",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.UpsertCallMembersResponse"),
			**kwargs,
		)

	def DeleteCallMembers(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/DeleteCallMembers",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.DeleteCallMembersResponse"),
			**kwargs,
		)

	def SendEvent(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/SendEvent",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.SendEventResponse"),
			**kwargs,
		)

	def SendCustomEvent(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/SendCustomEvent",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.SendCustomEventResponse"),
			**kwargs,
		)

	def ReportCallStats(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/ReportCallStats",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.ReportCallStatsResponse"),
			**kwargs,
		)

	def ReportCallStatEvent(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/ReportCallStatEvent",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.ReportCallStatEventResponse"),
			**kwargs,
		)

	def ReviewCall(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/ReviewCall",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.ReviewCallResponse"),
			**kwargs,
		)

	def ReportIssue(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.client_v1_rpc.ClientRPC/ReportIssue",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.client_v1_rpc.ReportIssueResponse"),
			**kwargs,
		)
